@@ -3,14 +3,15 @@ BEGIN {
   $MooseX::Storage::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $MooseX::Storage::VERSION = '0.42';
+  $MooseX::Storage::VERSION = '0.43';
 }
-# git description: v0.41-3-gd759b12
+# git description: v0.42-1-g352d533
 
 use Moose qw(confess);
 
 use MooseX::Storage::Meta::Attribute::DoNotSerialize;
 use String::RewritePrefix ();
+use Module::Runtime 'use_module';
 
 sub import {
     my $pkg = caller();
@@ -47,7 +48,7 @@ sub _expand_role {
         my ($class, $param) = @$value;
 
         $class = $self->_rewrite_role_name($base => $class);
-        Class::MOP::load_class($class);
+        use_module($class);
 
         my $role = $class->meta->generate_role(parameters => $param);
 
@@ -55,7 +56,7 @@ sub _expand_role {
         return $role->name;
     } else {
         my $class = $self->_rewrite_role_name($base, $value);
-        Class::MOP::load_class($class);
+        use_module($class);
 
         my $role = $class;
 
